@@ -7,7 +7,6 @@ import click_log
 import glob
 import json
 import logging
-import re
 import requests
 from pathlib import Path
 from pprint import pprint
@@ -17,31 +16,31 @@ from zipfile import ZipFile, ZIP_DEFLATED
 
 from requests.sessions import Session
 
+from fluidtopics.connector.model.metadata import SemanticMetadata
+
 from .ftmap import FTMap
-from .metadata import get_md_metas
+from .metadata import FT_ORIGIN_ID, FT_LANG, get_md_metas
 from . import __version__ as md2ft_version
 
 logger = logging.getLogger("fluidtopics.markdown")
 click_log.basic_config(logger)
 
-CONTEXT_SETTINGS = dict(help_option_names=['-h', '--help'])
-RE_H1_MD = re.compile("^# (.*)$")
+CONTEXT_SETTINGS = dict(help_option_names=["-h", "--help"])
 
 
 class MD2FTError(Exception):
     pass
 
 
-def prepare_ft_session(
-        portal_base_url: str,
-        user: str,
-        passwd: str) -> Session:
+def prepare_ft_session(portal_base_url: str, user: str, passwd: str) -> Session:
     "Prepare an FT session to call API"
     ft_session = requests.Session()
     login_url = portal_base_url + "/api/authentication/login"
     rep = ft_session.post(login_url, json={"login": user, "password": passwd})
     if not rep.ok:
-        raise MD2FTError(f"Cannot log in to FT portal {login_url} (user={user}, password=XXX): {rep.content}")
+        raise MD2FTError(
+            f"Cannot log in to FT portal {login_url} (user={user}, password=XXX): {rep.content}"
+        )
     return ft_session
 
 
@@ -56,20 +55,27 @@ def prune_empty_dir(content: Dict[str, dict]) -> Dict[str, dict]:
         if "childs" in node:
             new_childs = prune_empty_dir(node["childs"])
             # node is a directory without content and no child
-            if "ft:originID" in node["value"] and not new_childs:
+            if FT_ORIGIN_ID in node["value"] and not new_childs:
                 to_delete.append(k)
     for k in to_delete:
         del content[k]
     return content
 
 
-def dir_content(curdir: Path, relto: Path, skip: List[Path], meta_include_list: List[str],
-                implicit_meta: bool = False, dev_mode: bool = False) -> Dict[str, dict]:
-    """Recursively Collect the directory content starting at curdir
-    """
+def dir_content(
+    curdir: Path,
+    relto: Path,
+    skip: List[Path],
+    meta_include_list: List[str],
+    implicit_meta: bool = False,
+    dev_mode: bool = False,
+) -> Dict[str, dict]:
+    """Recursively Collect the directory content starting at curdir"""
     content = {}
     # Recursively loop over the curdir + sort dir using filename
-    for file in sorted(curdir.iterdir(), key=lambda f: f.name):
+    # we put README file first in any case in order to ensure proprer handling
+    # of potential content in READMEs
+    for file in sorted(curdir.iterdir(), key=lambda f: "    README.md" if f.name == "README.md" else f.name):
         if file.relative_to(relto) in skip:
             logger.debug(f"Skipping {file.as_posix()} as told.")
             continue
@@ -80,41 +86,80 @@ def dir_content(curdir: Path, relto: Path, skip: List[Path], meta_include_list:
                 continue
             dirdesc = file / "README.md"
             if dirdesc.exists():
-                dirmetas, with_content = get_md_metas(dirdesc)  # We handle default title for directory differently...
-                dirtitle = dirmetas.get("ft:title", file.name)
+                dirmetas, with_content = get_md_metas(
+                    dirdesc
+                )  # We handle default title for directory differently...
+                dirtitle = dirmetas.get(SemanticMetadata.TITLE, file.name)
                 logger.debug(f"Found directory description in {dirdesc}")
                 skip.append(dirdesc.relative_to(relto))
                 if meta_include_list:
                     audience = dirmetas.get("audience", None)
                     if audience is None:
                         logger.warning(
-                            f"Skipping {file.relative_to(relto).as_posix()} no audience given as meta while include_list = {meta_include_list}")
+                            f"Skipping {file.relative_to(relto).as_posix()} no audience given as meta while include_list = {meta_include_list}"
+                        )
                         continue
                     elif audience not in meta_include_list:
                         logger.warning(
-                            f"Skipping {file.relative_to(relto).as_posix()} as audience={audience} not in include_list = {meta_include_list}")
+                            f"Skipping {file.relative_to(relto).as_posix()} as audience={audience} not in include_list = {meta_include_list}"
+                        )
                         continue
                 # If README with metas + content => create href
                 if with_content:
                     content[relf_posix] = {
-                        "value": {"href": dirdesc.relative_to(relto).as_posix(), "ft:title": dirtitle, "metas": dirmetas},
-                        "childs": dir_content(file, relto, skip, meta_include_list, implicit_meta, dev_mode)
+                        "value": {
+                            "href": dirdesc.relative_to(relto).as_posix(),
+                            SemanticMetadata.TITLE: dirtitle,
+                            "metas": dirmetas,
+                        },
+                        "childs": dir_content(
+                            file,
+                            relto,
+                            skip,
+                            meta_include_list,
+                            implicit_meta,
+                            dev_mode,
+                        ),
                     }
                 # if README with metas only => create ft:originID (ToC entry only)
                 else:
                     content[relf_posix] = {
-                        "value": {"ft:originID": f_posix, "ft:title": dirtitle, "metas": dirmetas},
-                        "childs": dir_content(file, relto, skip, meta_include_list, implicit_meta, dev_mode)
+                        "value": {
+                            FT_ORIGIN_ID: f_posix,
+                            SemanticMetadata.TITLE: dirtitle,
+                            "metas": dirmetas,
+                        },
+                        "childs": dir_content(
+                            file,
+                            relto,
+                            skip,
+                            meta_include_list,
+                            implicit_meta,
+                            dev_mode,
+                        ),
                     }
             # if no README => create ft:originID from dir title (ToC entry only)
             else:
                 if not implicit_meta:
-                    raise MD2FTError(f"No README.md in directory {file} while in explicit mode, add one with an 'ft:title' meta.")
+                    raise MD2FTError(
+                        f"No README.md in directory {file} while in explicit mode, add one with an 'ft:title' meta."
+                    )
                 else:
                     # provide default value for directory description in implicit mode
                     content[relf_posix] = {
-                        "value": {"ft:originID": f_posix, "ft:title": file.name, "metas": {}},
-                        "childs": dir_content(file, relto, skip, meta_include_list, implicit_meta, dev_mode)
+                        "value": {
+                            FT_ORIGIN_ID: f_posix,
+                            SemanticMetadata.TITLE: file.name,
+                            "metas": {},
+                        },
+                        "childs": dir_content(
+                            file,
+                            relto,
+                            skip,
+                            meta_include_list,
+                            implicit_meta,
+                            dev_mode,
+                        ),
                     }
 
         elif file.is_file() and file.match("*.md"):
@@ -123,35 +168,53 @@ def dir_content(curdir: Path, relto: Path, skip: List[Path], meta_include_list:
             if meta_include_list:
                 if audience is None:
                     logger.warning(
-                        f"Skipping {file.relative_to(relto).as_posix()} no audience given as meta while include_list = {meta_include_list}")
+                        f"Skipping {file.relative_to(relto).as_posix()} no audience given as meta while include_list = {meta_include_list}"
+                    )
                     continue
                 elif audience not in meta_include_list:
                     logger.warning(
-                        f"Skipping {file.relative_to(relto).as_posix()} as audience={audience} not in include_list = {meta_include_list}")
+                        f"Skipping {file.relative_to(relto).as_posix()} as audience={audience} not in include_list = {meta_include_list}"
+                    )
                     continue
-            if metas.get("ft:title", None) is not None:
-                content[relf_posix] = {"value": {"href": relf_posix, "ft:title": metas["ft:title"], "metas": metas}}
+            if metas.get(SemanticMetadata.TITLE, None) is not None:
+                content[relf_posix] = {
+                    "value": {
+                        "href": relf_posix,
+                        SemanticMetadata.TITLE: metas[SemanticMetadata.TITLE],
+                        "metas": metas,
+                    }
+                }
             else:
                 if dev_mode:
-                    logger.warning(f"Skipping {file.as_posix()} no ft:title given as meta.")
+                    logger.warning(
+                        f"Skipping {file.as_posix()} no ft:title given as meta."
+                    )
                 else:
-                    raise MD2FTError(f"no meta ft:title or # title found in {file.as_posix()}")
+                    raise MD2FTError(
+                        f"no meta ft:title or # title found in {file.as_posix()}"
+                    )
     return content
 
 
 def _create_zip_file(output, pinput, image_dir, ftmap_file, collected_files):
-    with ZipFile(output, mode='w', compression=ZIP_DEFLATED) as archive:
+    with ZipFile(output, mode="w", compression=ZIP_DEFLATED) as archive:
         archive.writestr("generated.ftmap", data=ftmap_file.read())
         # NB: we need to use glob.glob and not pathlib.Path.rglob
         #     because of: https://bugs.python.org/issue33428
         #     see also: https://stackoverflow.com/questions/46529760/getting-glob-to-follow-symlinks-in-python
         for fn in glob.glob(f"{str(pinput)}/**/*", recursive=True):
             f = Path(fn)
-            if f.match('*.ftmap'):
+            if f.match("*.ftmap"):
                 continue
             if f.is_dir() or ((pinput / Path(image_dir)) in f.parents):
                 archive.write(f, arcname=f.relative_to(pinput))
-            elif f.is_file() and f.suffix.lower() in ['.png', '.jpg', '.jpeg', '.gif', '.svg']:
+            elif f.is_file() and f.suffix.lower() in [
+                ".png",
+                ".jpg",
+                ".jpeg",
+                ".gif",
+                ".svg",
+            ]:
                 logger.debug(f"f={f}, arcname={f.relative_to(pinput)}")
                 archive.write(f, arcname=f.relative_to(pinput))
             elif f.relative_to(pinput) in collected_files:
@@ -163,11 +226,12 @@ def _create_zip_file(output, pinput, image_dir, ftmap_file, collected_files):
 
 
 def do_collect(
-            input: str, output: str,
-            included_audiences: List[str],
-            implicit_meta: bool,
-            dev_mode: bool = False
-            ):
+    input: str,
+    output: str,
+    included_audiences: List[str],
+    implicit_meta: bool,
+    dev_mode: bool = False,
+):
     """Collect markdown files and create FTML archive with a book FT Map
     built from the metadata found in the markdown files (unless implicit_meta is True)
     The created archive may then be uploaded to FT portal using `upload`.
@@ -178,16 +242,16 @@ def do_collect(
     # We always collect metas from root README is there is some
     if root_readme:
         root_readme = root_readme[0]
-        metas, _ = get_md_metas(root_readme)
+        metas, root_content = get_md_metas(root_readme)
     if implicit_meta:
         logger.debug("Implicit meta MODE")
         implicit_metas_values = {
             # if implicit meta is set to True, build the title from pinput dir name
             "media_dir": "images",
-            "ft:title": f"{pinput.name}",
-            "ft:originID": input,
+            SemanticMetadata.TITLE: f"{pinput.name}",
+            FT_ORIGIN_ID: input,
             "Category": "Technical Notes",
-            "audience": "internal"
+            "audience": "internal",
         }
         # Replace provided metas value if any
         if metas:
@@ -200,25 +264,37 @@ def do_collect(
     logger.debug(f"root metas = {metas}")
     # Get media_dir value or use default one (images/)
     image_dir = metas.get("media_dir", "images")
+
     skipped = [Path(image_dir)]
-    if root_readme and not implicit_meta:
+    # skip root README iff there is NO content in it
+    # and we are in not implicit mode
+    if not implicit_meta and not root_content:
         skipped.append(root_readme.relative_to(pinput))
     # Recursively collect md files beginning at pinput
-    collected = dir_content(pinput, pinput, skipped, meta_include_list=included_audiences, implicit_meta=implicit_meta, dev_mode=dev_mode)
+    collected = dir_content(
+        pinput,
+        pinput,
+        skipped,
+        meta_include_list=included_audiences,
+        implicit_meta=implicit_meta,
+        dev_mode=dev_mode,
+    )
     # Clean up empty dirs (i.e. which do not contain md files)
     collected = prune_empty_dir(collected)
     logger.debug(f"collected= {collected}")
-    if "ft:title" not in metas:
+    if SemanticMetadata.TITLE not in metas:
         raise MD2FTError(f"No ft:title in {root_readme}.")
-    if "ft:originID" not in metas:
+    if FT_ORIGIN_ID not in metas:
         raise MD2FTError(f"No ft:originID in {root_readme}.")
     # Init FTMAP with mandatory prop: ft:title, ft:originID
-    ftmap = FTMap(title=metas["ft:title"],
-                  origin_id=metas["ft:originID"],
-                  editorial_type=metas.get("ft:editorialType", "book"),
-                  lang=metas.get("ft:lang", "en-US"))
+    ftmap = FTMap(
+        title=metas[SemanticMetadata.TITLE],
+        origin_id=metas[FT_ORIGIN_ID],
+        editorial_type=metas.get(SemanticMetadata.EDITORIAL_TYPE, "book"),
+        lang=metas.get(FT_LANG, "en-US"),
+    )
     if "metas" in metas:
-        ft_metas = json.loads(metas["metas"].replace("'", "\""))
+        ft_metas = json.loads(metas["metas"].replace("'", '"'))
         ft_metas = {k: v["value"] for k, v in ft_metas.items()}
         logger.warning("Using '[_metadata_:metas]:-' for metadata is deprecated")
         logger.warning("Use '[_metadata_:key]:- \"value\"' for each metadata")
@@ -228,6 +304,8 @@ def do_collect(
     ftmap.add_metas(ftmap.root, ft_metas)
     # Build FTMAP ToC with collected items + return files list to be zipped
     collected_files = ftmap.populate_toc(ftmap.get_toptoc(), None, collected.values())
+    if len(collected_files) == 0:
+        raise MD2FTError(f"0 collected file, check your input ({input}) directory and/or --include rules.")
     logger.info(f"Collected {len(collected_files)} markdown files in FTMap.")
     logger.debug(f"FTMap collected_files= {collected_files}")
     # Create the output zip file
@@ -238,29 +316,35 @@ def do_collect(
 
 
 def do_publish(
-        zip: Path, portal_base_url: str,
-        user: str, passwd: str,
-        source_id: str,
-        dry_run: bool):
-    """Upload and publish an FTML archive to an FT portal.
-    """
+    zip: Path,
+    portal_base_url: str,
+    user: str,
+    passwd: str,
+    source_id: str,
+    dry_run: bool,
+):
+    """Upload and publish an FTML archive to an FT portal."""
     if not dry_run:
         ft_session = prepare_ft_session(portal_base_url, user, passwd)
         # Verify that the server is reachable and has FTML source exists
         list_sources_url = f"{portal_base_url}/api/admin/khub/sources"
         rep = ft_session.get(list_sources_url)
         if rep.status_code in [HTTPStatus.UNAUTHORIZED, HTTPStatus.FORBIDDEN]:
-            raise MD2FTError(f"Server rejected credentials as Unauthorized ({rep.status_code}).")
+            raise MD2FTError(
+                f"Server rejected credentials as Unauthorized ({rep.status_code})."
+            )
         elif rep.status_code == HTTPStatus.NOT_FOUND:
-            raise MD2FTError(f'The instance id or the API in "{list_sources_url}" is not found ({rep.status_code}).')
+            raise MD2FTError(
+                f'The instance id or the API in "{list_sources_url}" is not found ({rep.status_code}).'
+            )
         elif not rep.ok:
             raise MD2FTError(rep.text)
 
     # Upload FTML zip archive
     if type(zip) == str:
-        zipfile = {'file': ("md2ft_" + Path(zip).name, Path(zip).open('rb'))}
+        zipfile = {"file": ("md2ft_" + Path(zip).name, Path(zip).open("rb"))}
     else:
-        zipfile = {'file': ("md2ft_" + Path(zip.name).name, zip)}
+        zipfile = {"file": ("md2ft_" + Path(zip.name).name, zip)}
     post_url = f"{portal_base_url}/api/admin/khub/sources/{source_id}/upload"
 
     if not dry_run:
@@ -272,13 +356,12 @@ def do_publish(
         else:
             raise MD2FTError(rep.text)
     else:
-        logger.info(f"DRY RUN: {zipfile['file'][0]} file NOT published on {portal_base_url}.")
+        logger.info(
+            f"DRY RUN: {zipfile['file'][0]} file NOT published on {portal_base_url}."
+        )
 
 
-def _get_meta_values(
-        key: str,
-        metadatas: List[dict],
-        first_value_only: bool):
+def _get_meta_values(key: str, metadatas: List[dict], first_value_only: bool):
     "Extract a meta FT API json"
     meta = next((keys for keys in metadatas if keys["key"] == key), None)
     if meta is not None:
@@ -294,35 +377,44 @@ def _get_meta_values(
 
 
 def do_unpublish(
-        portal_base_url: str,
-        user: str,
-        passwd: str,
-        source_id: str,
-        dry_run: bool,
-        do_it: bool,
-        select: str):
+    portal_base_url: str,
+    user: str,
+    passwd: str,
+    source_id: str,
+    dry_run: bool,
+    do_it: bool,
+    select: str,
+):
     """
-        Delete selected publications by :
-        - lastEdtion : the old version of the publications (older than the last publish)
-        - title : delete the publication with the corresponding title
+    Delete selected publications by :
+    - lastEdtion : the old version of the publications (older than the last publish)
+    - title : delete the publication with the corresponding title
     """
     if not dry_run:
         # Prepare a FT session
         ft_session = prepare_ft_session(portal_base_url, user, passwd)
 
         # Get all the maps from md2ft source
-        list_maps = f"{portal_base_url}/api/admin/khub/publications?ft:sourceId={source_id}"
+        list_maps = (
+            f"{portal_base_url}/api/admin/khub/publications?ft:sourceId={source_id}"
+        )
         r = ft_session.get(list_maps)
         if r.status_code == HTTPStatus.UNAUTHORIZED:
-            logger.fatal(f"Server rejected credentials as Unauthorized ({r.status_code}).")
+            logger.fatal(
+                f"Server rejected credentials as Unauthorized ({r.status_code})."
+            )
         if r.status_code == HTTPStatus.NOT_FOUND:
-            logger.fatal(f'The instance id or the API in "{list_maps}" is not found ({r.status_code}).')
+            logger.fatal(
+                f'The instance id or the API in "{list_maps}" is not found ({r.status_code}).'
+            )
         r.raise_for_status()
         list_maps_json = r.json()
 
         # Exist if no publication or source does not exist
         if list_maps_json["count"] == 0:
-            logger.info(f"No publications in this source_id or the source: {source_id} doesn't exist")
+            logger.info(
+                f"No publications in this source_id or the source: {source_id} doesn't exist"
+            )
             return
 
         # Prepare documents dictionary for the specified source id
@@ -337,23 +429,30 @@ def do_unpublish(
         else:
             metavalue = None
 
-        logger.debug(f"Selecting documents with metaname={metaname} and metavalue={metavalue}...")
+        logger.debug(
+            f"Selecting documents with metaname={metaname} and metavalue={metavalue}..."
+        )
         if metaname == "ft:lastEdition":
             # Get the maxDate (ie the last date of publish)
-            latestDates = [_get_meta_values(metaname, metas, True) for metas in documents.values()]
+            latestDates = [
+                _get_meta_values(metaname, metas, True) for metas in documents.values()
+            ]
             logger.debug(f"latest dates are: {latestDates}")
             latestDate = max(latestDates)
             logger.debug(f"latest date is: {latestDate}")
             # Remove the newest publication to have a dict of publication to delete
-            selected_documents = \
-                {
-                    key: metas for key, metas in documents.items()
-                    if _get_meta_values(metaname, metas, True) != latestDate
-                }
+            selected_documents = {
+                key: metas
+                for key, metas in documents.items()
+                if _get_meta_values(metaname, metas, True) != latestDate
+            }
         else:
             # Filter the map to only delete documents with given metavalue for metaname
-            selected_documents = \
-                {key: metas for key, metas in documents.items() if metavalue in _get_meta_values(metaname, metas, False)}
+            selected_documents = {
+                key: metas
+                for key, metas in documents.items()
+                if metavalue in _get_meta_values(metaname, metas, False)
+            }
 
         if selected_documents:
             # Iter on each publication to delete
@@ -365,17 +464,27 @@ def do_unpublish(
 
                     if r.status_code == HTTPStatus.OK:
                         answer = r.json()
-                        logger.info(f" ID MAP {id_to_delete} deleted on {portal_base_url}.")
+                        logger.info(
+                            f" ID MAP {id_to_delete} deleted on {portal_base_url}."
+                        )
                         pprint(answer)
                     r.raise_for_status()
                 else:
-                    logger.info(f"Would delete document id={id_to_delete} (whose metas={metas}) on {portal_base_url}.")
+                    logger.info(
+                        f"Would delete document id={id_to_delete} (whose metas={metas}) on {portal_base_url}."
+                    )
             if not do_it:
-                logger.info("If you want to delete the previous publications do add --do-it parameter")
+                logger.info(
+                    "If you want to delete the previous publications do add --do-it parameter"
+                )
         else:
-            logger.info(f"No publications selected with <<{select}>> from source_id : {source_id} on portal {portal_base_url}")
+            logger.info(
+                f"No publications selected with <<{select}>> from source_id : {source_id} on portal {portal_base_url}"
+            )
     else:
-        logger.info(f"DRY RUN: No publications deleted from source_id : {source_id} on portal : {portal_base_url}.")
+        logger.info(
+            f"DRY RUN: No publications deleted from source_id : {source_id} on portal : {portal_base_url}."
+        )
 
 
 @click.group(context_settings=CONTEXT_SETTINGS)
@@ -394,7 +503,8 @@ collect_opts = [
         type=click.Path(file_okay=False, dir_okay=True, readable=True),
     ),
     click.option(
-        "--include", "included_audiences",
+        "--include",
+        "included_audiences",
         metavar="<audience tag>",
         multiple=True,
         required=False,
@@ -421,31 +531,35 @@ publish_opts = [
         "portal_base_url",
         metavar="<FT_portal_base_url>",
         required=True,
-        type=click.STRING
+        type=click.STRING,
     ),
     click.option(
-        "-u", "--user",
+        "-u",
+        "--user",
+        required=True,
         type=click.STRING,
-        default="root@fluidtopics.com",
-        show_default=True,
         metavar="<user>",
-        help="The FT user"
+        help="The FT user",
+        prompt="Please, provide a FT user account",
     ),
     click.option(
-        "-p", "--passwd",
+        "-p",
+        "--passwd",
+        required=True,
         type=click.STRING,
-        default="change_it",
-        show_default=True,
         metavar="<password>",
-        help="The FT password"
+        help="The FT password",
+        prompt="Please, provide the FT user password",
+        hide_input=True,
     ),
     click.option(
-        "-s", "--source-id",
+        "-s",
+        "--source-id",
         type=click.STRING,
         default="ftml",
         show_default=True,
         metavar="<source_id>",
-        help="The FT source ID"
+        help="The FT source ID",
     ),
     click.option(
         "--dry-run",
@@ -462,25 +576,32 @@ def add_options(options):
         for option in reversed(options):
             func = option(func)
         return func
+
     return _add_options
 
 
 @cli.command("collect")
 @add_options(collect_opts)
 @click.option(
-    "-o", "--output", "output",
+    "-o",
+    "--output",
+    "output",
     metavar="<archive_file>",
     type=click.Path(file_okay=True, dir_okay=False, writable=True),
     help="output path of the FTML archive to be created",
     show_default=True,
-    default="ftml_content.zip")
-def collect(input: str, output: str,
-            included_audiences: List[str],
-            implicit_meta: bool,
-            dev_mode: bool):
+    default="ftml_content.zip",
+)
+def collect(
+    input: str,
+    output: str,
+    included_audiences: List[str],
+    implicit_meta: bool,
+    dev_mode: bool,
+):
     """Collect documentation and create an FTML archive based on the metadata found in
-       the Markdown files (unless implicit_meta is set as True).
-       The archive may then be published to a Fluid Topics portal using the `publish` command.
+    the Markdown files (unless implicit_meta is set as True).
+    The archive may then be published to a Fluid Topics portal using the `publish` command.
     """
     do_collect(input, output, included_audiences, implicit_meta, dev_mode)
     logger.info(f"Written FTML archive in: {output}.")
@@ -491,17 +612,18 @@ def collect(input: str, output: str,
 @cli.command("collect_and_publish")
 @add_options(collect_opts)
 @add_options(publish_opts)
-def collect_and_publish(input: str,
-                        included_audiences: List[str],
-                        implicit_meta: bool,
-                        dev_mode: bool,
-                        portal_base_url: str,
-                        user: str,
-                        passwd: str,
-                        source_id: str,
-                        dry_run: bool):
-    """Collect upload and publish documentation to an FT portal.
-    """
+def collect_and_publish(
+    input: str,
+    included_audiences: List[str],
+    implicit_meta: bool,
+    dev_mode: bool,
+    portal_base_url: str,
+    user: str,
+    passwd: str,
+    source_id: str,
+    dry_run: bool,
+):
+    """Collect upload and publish documentation to an FT portal."""
     with NamedTemporaryFile(mode="r+b", suffix=".zip") as tempzip:
         logger.debug(f"tempzip={tempzip.name}")
         do_collect(input, tempzip, included_audiences, implicit_meta)
@@ -514,16 +636,18 @@ def collect_and_publish(input: str,
 @click.argument(
     "zip",
     required=True,
-    type=click.Path(exists=True, file_okay=True, dir_okay=False, readable=True)
+    type=click.Path(exists=True, file_okay=True, dir_okay=False, readable=True),
 )
 @add_options(publish_opts)
-def publish(zip: Path, portal_base_url: str,
-            user: str,
-            passwd: str,
-            source_id: str,
-            dry_run: bool):
-    """Upload and publish an FTML archive to an FT portal.
-    """
+def publish(
+    zip: Path,
+    portal_base_url: str,
+    user: str,
+    passwd: str,
+    source_id: str,
+    dry_run: bool,
+):
+    """Upload and publish an FTML archive to an FT portal."""
     do_publish(zip, portal_base_url, user, passwd, source_id, dry_run)
 
 
@@ -548,17 +672,17 @@ def publish(zip: Path, portal_base_url: str,
     """,
 )
 def delete_book(
-        portal_base_url: str,
-        user: str,
-        passwd: str,
-        source_id: str,
-        dry_run: bool,
-        do_it: bool,
-        select: str):
-    """ Delete all publications older than the latest ones from an FT portal (from last md2ft publish) 
-    """
+    portal_base_url: str,
+    user: str,
+    passwd: str,
+    source_id: str,
+    dry_run: bool,
+    do_it: bool,
+    select: str,
+):
+    """Delete all publications older than the latest ones from an FT portal (from last md2ft publish)"""
     do_unpublish(portal_base_url, user, passwd, source_id, dry_run, do_it, select)
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     cli()
